@@ -5,31 +5,48 @@ session_start_time = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(time.time
 
 
 class Column:
-    def __init__(self, name=None, title=None, visible=True, width=50):
-        self.name = name
-        self.title = title if title else name
+    def __init__(self, title=None, query=None, visible=True, width=0):
+        self.title = title
+        self.query = query if query else title
+        self.default_visiblity = visible
         self.visible = visible
+        self.default_width = width
         self.width = width
 
     def set_visibility(self, visible):
         self.visible = visible
 
+    def set_data(self, data):
+        self.visible = data.get('visible', self.default_visiblity)
+        self.width = data.get('width', self.default_width)
+
+    def get_data(self):
+        data = {}
+
+        if self.default_width:
+            if self.default_width != self.width:
+                data['width'] = self.width
+        if self.default_visiblity != self.visible:
+            data['visible'] = self.visible
+        
+        return data
+
 
 default_columns = [
-    Column("TimeStamp", "Time", width=130, visible=True),
-    Column("LogLevel", "'Level#'", width=40, visible=False),
-    Column("LogLevelName", "Level", width=60, visible=True),
+    Column("Time", "TimeStamp", width=130, visible=True),
+    Column("'Level#'", "LogLevel", width=40, visible=False),
+    Column("Level", "LogLevelName", width=60, visible=True),
     Column("Source", width=200, visible=True),
     Column("Module", width=100, visible=False),
-    Column("FuncName || ':' || LineNo", "'Func:Line'", width=120, visible=True),
-    Column("FuncName", "Func", width=120, visible=False),
-    Column("LineNo", "Line", width=40, visible=False),
+    Column("'Func:Line'", "FuncName || ':' || LineNo", width=120, visible=True),
+    Column("Func", "FuncName", width=120, visible=False),
+    Column("Line", "LineNo", width=40, visible=False),
     Column("Args", width=100, visible=False),
     Column("Exception", width=100, visible=False),
     Column("Process", width=100, visible=False),
     Column("Thread", width=100, visible=False),
     Column("ThreadName", width=100, visible=False),
-    Column("Message", width=100, visible=True),
+    Column("Message", visible=True),
 ]
 
 
@@ -49,8 +66,12 @@ class LogProfile:
     def visible_columns(self):
         return [c for c in self.columns if c.visible]
 
+    @property
+    def column_data(self):
+        return {c.title: c.get_data() for c in self.columns if c.get_data()}
+
     def get_log_level_column(self):
-        return [c.name for c in self.visible_columns].index('LogLevelName')
+        return [c.title for c in self.visible_columns].index('Level')
 
     def set_filter(self, filt):
         self.text_filter = filt['text']
@@ -59,16 +80,20 @@ class LogProfile:
         self.current_session_only = filt['current_session_only']
         self.query_limit = filt['query_limit']
 
+    def set_columns(self, column_data):
+        for c in self.columns:
+            c.set_data(column_data.get(c.title, {}))
+
     def build_query(self, row_count):
         query = "SELECT "
 
         columns = []
         for col in self.columns:
             if col.visible:
-                if col.name != col.title:
-                    columns.append(f'{col.name} AS {col.title}')
+                if col.title != col.query:
+                    columns.append(f'{col.query} AS {col.title}')
                 else:
-                    columns.append(f'{col.name}')
+                    columns.append(f'{col.title}')
 
         query += ', '.join(columns)
         query += " FROM 'log'"
